@@ -24,9 +24,9 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py 2528 2007-07-09 14:41:22Z wwalker $"
-__version__   = "$Revision: 2528 $"
-__date__      = "$Date: 2007-07-09 10:41:22 -0400 (Mon, 09 Jul 2007) $"
+__id__        = "$Id: speechserver.py 2548 2007-07-21 21:46:43Z wwalker $"
+__version__   = "$Revision: 2548 $"
+__date__      = "$Date: 2007-07-21 17:46:43 -0400 (Sat, 21 Jul 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -200,12 +200,18 @@ class SpeechServer(object):
         event_string = keynames.getKeyName(event_string)
 
         if type == orca.KeyEventType.LOCKING_LOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
             event_string += " " + _("on")
         elif type == orca.KeyEventType.LOCKING_UNLOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
             event_string += " " + _("off")
 
         debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + event_string +"'")
-        log.info("'%s'" % event_string)
+        log.info("speakKeyEvent utterance='%s'" % event_string)
 
         self.speak(event_string, acss=voice)
 
@@ -260,7 +266,7 @@ class SpeechServer(object):
         for [context, acss] in utteranceIterator:
             debug.println(debug.LEVEL_INFO,
                           "SPEECH OUTPUT: '" + context.utterance + "'")
-            log.info("'%s'" % context.utterance)
+            log.info("sayAll utterance='%s'" % context.utterance)
             self.speak(context.utterance, acss)
 
     def increaseSpeechRate(self, step=5):
